@@ -2,7 +2,7 @@ package Test2::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000045';
+our $VERSION = '0.000048';
 
 use Scalar::Util qw/blessed/;
 use Test2::Util qw/try/;
@@ -105,6 +105,9 @@ sub convert {
         return Test2::Compare::Scalar->new(item => $nested);
     }
 
+    return Test2::Compare::DeepRef->new(input => $thing)
+        if $type eq 'REF';
+
     return Test2::Compare::Ref->new(input => $thing)
         if $type;
 
