@@ -2,7 +2,7 @@ package Test2::Mock;
 use strict;
 use warnings;
 
-our $VERSION = '0.000045';
+our $VERSION = '0.000048';
 
 use Carp qw/croak confess/;
 our @CARP_NOT = (__PACKAGE__);
@@ -336,7 +336,7 @@ sub _inject {
         my $orig = $self->current("$sig$sym");
 
         croak "Cannot override '$sig$class\::$sym', symbol is not already defined"
-            unless $orig || $add;
+            unless $orig || $add || ($sig eq '&' && $class->can($sym));
 
         # Cannot be too sure about scalars in globs
         croak "Cannot add '$sig$class\::$sym', symbol is already defined"
@@ -430,6 +430,7 @@ sub _purge {
 sub DESTROY {
     my $self = shift;
 
+    delete $self->{+CHILD};
     $self->reset_all if $self->{+_SYMBOLS};
 
     delete $INC{$self->file} if $self->{+_BLOCKED_LOAD};
